@@ -2,6 +2,7 @@
 CLI runner for Ledger2BQL utility.
 """
 import sys
+from importlib.metadata import version, PackageNotFoundError
 from dotenv import find_dotenv, load_dotenv
 
 from .ledger_bal_to_bql import main as bal_main
@@ -11,6 +12,11 @@ from .ledger_reg_to_bql import main as reg_main
 def main():
     """main entry point"""
     if len(sys.argv) < 2:
+        try:
+            v = version("ledger2bql")
+        except PackageNotFoundError:
+            v = "local"
+        print(f"ledger2bql v{v}")
         print("Usage: ledger2bql [bal|b|reg|r] [options]")
         sys.exit(1)
 
