@@ -1,8 +1,14 @@
+'''
+Shared utilities.
+'''
 import argparse
 import os
+import re
+from decimal import Decimal
 import beanquery
 from tabulate import tabulate
 
+
 def get_beancount_file_path():
     """Placeholder for get_beancount_file_path."""
     # This function should ideally get the path to the beancount file, e.g., from an environment variable.
@@ -12,6 +18,7 @@ def get_beancount_file_path():
         raise ValueError("BEANCOUNT_FILE environment variable not set.")
     return beancount_file
 
+
 def add_common_arguments(parser):
     """Placeholder for add_common_arguments."""
     parser.add_argument(
@@ -24,11 +31,12 @@ def add_common_arguments(parser):
         help='Start date for the query (YYYY-MM-DD).'
     )
     parser.add_argument(
-        '--end', '-E',
+        '--end', '-e',
         help='End date for the query (YYYY-MM-DD).'
     )
     parser.add_argument(
-        '--empty', '-e',
+        '--empty',
+        # '-e',
         action='store_true',
         help='Show accounts with zero balance (for consistency with ledger-cli, no effect on BQL).'
     )
@@ -43,6 +51,12 @@ def add_common_arguments(parser):
         type=int,
         help="Limit the number of results."
     )
+    parser.add_argument(
+        '--amount', '-a',
+        action='append',
+        help='Filter by amount. Format: [>|>=|<|<=|=]AMOUNT[CURRENCY]. E.g. >100EUR'
+    )
+
 
 def run_bql_query(query: str, book: str) -> list:
     """
@@ -58,17 +72,42 @@ def run_bql_query(query: str, book: str) -> list:
 
     return result
 
-def execute_bql_command(create_parser_func, parse_query_func, format_output_func, headers, alignments, **kwargs):
+
+def parse_amount_filter(amount_str):
     """
-    Executes a BQL command by parsing arguments, constructing a query, running it, and formatting output.
+    Parses an amount filter string into a (operator, value, currency) tuple.
+    """
+    match = re.match(r'([><]=?|=)?(-?\d+\.?\d*)([A-Z]{3})?', amount_str, re.IGNORECASE)
+    if not match:
+        raise ValueError(f"Invalid amount filter format: {amount_str}")
+    
+    op, val_str, cur = match.groups()
+    
+    op = op or '='
+    val = Decimal(val_str)
+    
+    if cur:
+        cur = cur.upper()
+    
+    return op, val, cur
+
+
+def execute_bql_command(create_parser_func, parse_query_func, format_output_func, 
+                        headers, alignments, **kwargs):
+    """
+    Executes a BQL command by parsing arguments, constructing a query, running it, 
+    and formatting output.
     """
     parser = create_parser_func()
-    args = parser.parse_args()
+    args, remaining_args = parser.parse_known_args()
+    if remaining_args:
+        if not args.account_regex:
+            args.account_regex = []
+        args.account_regex.extend(remaining_args)
 
     book = get_beancount_file_path()
 
     query = parse_query_func(args)
-
     output = run_bql_query(query, book)
 
     # Pass kwargs to format_output_func
@@ -86,4 +125,5 @@ def execute_bql_command(create_parser_func, parse_query_func, format_output_func
         headers.append("Running Total")
         alignments.append("right")
 
-    print(tabulate(formatted_output, headers=headers, tablefmt="psql", colalign=alignments))
+    print(tabulate(formatted_output, headers=headers, tablefmt="psql", 
+                   colalign=alignments))
